@@ -508,6 +508,23 @@ class DataClient(object):
         room = backbone.get_future_exam_classroom()
         return room
 
+    @staticmethod
+    def get_classroom_num_map(school_id):
+        """
+        获取教室编号映射表
+        :param school_id:
+        :return:
+        """
+        backbone = Backbone(school_id)
+        backbone.wrap_classroom_map()
+        return deepcopy(backbone.classroom_map)
+
+    @staticmethod
+    def delete_classroom(school_id, uid):
+        backbone = Backbone(school_id)
+        backbone.delete_classroom(uid)
+        return
+
 
 class DataClientV1(DataClient):
     @staticmethod
@@ -601,3 +618,9 @@ class DataClientV2(DataClient):
         backbone = BackboneV2(school_id)
         backbone.active_course_table(course_manager=course_table_manager, delete_other=delete_other)
         return True
+
+    @staticmethod
+    def delete_all_course_table(school_id):
+        backbone = BackboneV2(school_id)
+        backbone.delete_all_table_manager()
+        return True
