@@ -108,6 +108,15 @@ class Backbone(object):
         """
         self.album_map = self.nirvana_requester.wrap_map("get_album_list", ["name", "category"], "uid")
 
+    def delete_classroom(self, classroom_id):
+        """
+        删除教室
+        :param classroom_id: 教室id
+        :return:
+        """
+        print(">>> Delete course table")
+        self.nirvana_requester.delete_classroom(classroom_id)
+
     def delete_table_manager(self, manager_id):
         """
         删除整张课程表
@@ -368,6 +377,8 @@ class Backbone(object):
                 classroom.uid = classroom_id
             else:
                 res_data = self.nirvana_requester.create_classroom(classroom.nirvana_data)
+                if not res_data:
+                    print("创建教室{}失败".format(classroom.nirvana_data))
                 classroom.uid = res_data['uid']
             print("##### already create {} {}/{} classroom ####".format(classroom.name, index, len(classrooms)))
 
@@ -841,3 +852,8 @@ class BackboneV2(Backbone):
         self.course_manager = course_manager or self.course_manager
         semester = self.get_semester_list(params={"name": self.course_manager.semester_name})
         self.delete_other_table_manager(semester_id=semester[0]['uid'], remain=[self.course_manager.number])
+
+    def delete_all_table_manager(self):
+        managers = self.get_course_manager_list()
+        for manager in managers:
+            self.delete_table_manager(manager['uid'])
