@@ -19,11 +19,16 @@ TABLE_END_DATE = os.getenv("TABLE_END_DATE", "2020-01-12")
 TABLE_SEMESTER = os.getenv("TABLE_SEMESTER", "1")
 TABLE_YJS_SEMESTER = os.getenv("TABLE_YJS_SEMESTER", "第一学期")
 TABLE_YEAR = os.getenv("TABLE_YEAR", "2019-2020")
-
-SCHOOL_NAME = os.getenv("SCHOOL_NAME", "五楼229环境")
+SCHOOL_NAME = os.getenv("SCHOOL_NAME", "上海华二昆山国际学校")
 SCHOOL_SEASON = os.getenv("SCHOOL_SEASON", "winter")
 SEMESTER_NAME = os.getenv("SEMESTER_NAME", "当前学期")
 REST_TABLE_NAME = os.getenv("REST_TABLE_NAME", "全校作息")
+REST_TABLE_KEY1 = os.getenv("REST_TABLE_KEY1", "A-")
+REST_TABLE_KEY2 = os.getenv("REST_TABLE_KEY2", "B-")
+SUMMER_MORNING_LIMIT = os.getenv("SUMMER_MORNING_LIMIT", "12:30:00")
+SUMMER_AFTERNOON_LIMIT = os.getenv("SUMMER_AFTERNOON_LIMIT", "17:00:00")
+WINTER_MORNING_LIMIT = os.getenv("WINTER_MORNING_LIMIT", "12:30:00")
+WINTER_AFTERNOON_LIMIT = os.getenv("WINTER_AFTERNOON_LIMIT", "17:00:00")
 
 # redis
 REDIS_HOST = os.getenv("REDIS_HOST", "10.88.188.229")
