@@ -38,7 +38,7 @@ class ClassroomSync(BaseSync):
             self.building_list.add(parent_id)
 
     def extract_classroom(self):
-        sql = "SELECT id, areaname, fullname, pid, levf FROM mid_areainfo ORDER BY levf"
+        sql = "SELECT id, areaname, fullname, pid, levf FROM mid_areainfo WHERE updateflag='2'  ORDER BY levf"
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
@@ -60,6 +60,8 @@ class ClassroomSync(BaseSync):
     def add_classroom(self, name, number, fullname, building, floor):
         if name not in self.name_num:
             self.name_num[name] = number
+            if building:
+                building = building.split("/")[0]
             classroom = Classroom(number=number, name=name, building=building,
                                   floor=floor, school=self.school_id, category=RoomType.TYPE_PUBLIC)
             if fullname in self.fullname_section:
