@@ -18,11 +18,38 @@ class CourseSync(BaseSync):
         self.student_map = {}
         self.teacher_map = {}
         self.classroom_map = {}
-        self.class_set = set()
+        self.class_set = {}
+        self.classroom_set = {}
         self.class_name_num = {}
         self.rest_table = None
         self.semester = None
         self.course_name_list = []
+        self.slot_course_table = {}  # {"slot_id" : "course_table_name"}
+        self.course_container = {}  # {"course_table_name" : [course, course]}
+        self.rest_table_slot = {}  # {"rest_name": [slot_id, slot_id, slot_id]}
+        self.course_table_managers = {}
+        self.classroom_sign = {}
+        self.class_sign = {}
+
+    def create_course_manager(self):
+        """
+        根据多作息，创建多课表
+        :return:
+        """
+        begin_date, end_date = self.get_date_range(days=60)
+        for rest_name, slot_list in self.rest_table_slot.items():
+            course_table_name = "{}课表_{}".format(rest_name, str(uuid.uuid4())[:4])
+            course_table_number = get_md5_hash(course_table_name)[:20]
+            course_table_manager = CourseTableManagerV2(name=course_table_name, number=course_table_number,
+                                                        rest_name=rest_name, walking_mode=WalkingModeSet.WALKING,
+                                                        begin_date=begin_date, end_date=end_date,
+                                                        semester_name=self.semester.name)
+            for slot_id in slot_list:
+                self.slot_course_table[slot_id] = course_table_name
+            self.course_table_managers[course_table_name] = course_table_manager
+            self.class_set[course_table_name] = set()
+            self.classroom_set[course_table_name] = set()
+            self.course_container[course_table_name] = []
 
     # def get_double_map(self):
     #     double_name = {"C2-413": ["C2-413-1", "C2-413-2"],
@@ -39,10 +66,10 @@ class CourseSync(BaseSync):
     #     return double_number
 
     def get_double_map(self):
-        double_number = {"1": ["1_A", "1_B"],
-                         "2": ["2_A", "2_B"],
-                         "3": ["3_A", "3_B"],
-                         "4": ["4_A", "4_B"]}
+        double_number = {"1xx": ["1_A", "1_B"],
+                         "2xx": ["2_A", "2_B"],
+                         "3xx": ["3_A", "3_B"],
+                         "4xx": ["4_A", "4_B"]}
         return double_number
 
     def create_unique_course_name(self, subject_name, class_name):
@@ -60,7 +87,8 @@ class CourseSync(BaseSync):
         today, last_day = self.get_date_range()
         sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname " \
               "FROM mid_attendschedule " \
-              "WHERE coursedate > '{}' and coursedate <= '{}' ORDER BY weekday".format(today, last_day)
+              "WHERE updateflag!=3 and coursedate > '{}' and coursedate <= '{}' ORDER BY weekday".format(today,
+                                                                                                         last_day)
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
@@ -74,10 +102,20 @@ class CourseSync(BaseSync):
             if not num:
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
+            current_course_table = self.slot_course_table.get(slot_id)
+            if not current_course_table:
+                print("Can't Find SlotID {}".format(slot_id))
+                continue
             # ori_classroom_number = self.classroom_map.get(str(classroom_id))
             ori_classroom_number = str(classroom_id)
             classroom_numbers = double_number_map.get(ori_classroom_number, [ori_classroom_number])
             for classroom_number in classroom_numbers:
+                # 检测教室是否在其他作息课表出现,如果出现，就跳过
+                exist_classroom_sign = self.classroom_sign.get(classroom_number)
+                if exist_classroom_sign and current_course_table != exist_classroom_sign:
+                    print("该教室{}已在{}课表出现，请检查数据".format(classroom_number, exist_classroom_sign))
+                    continue
+
                 unique_key = "{}_{}_{}_{}".format(subject_name, classroom_number, slot_id, week)
                 course_number = get_md5_hash(unique_key)
                 if course_number not in self.course_map:
@@ -91,7 +129,15 @@ class CourseSync(BaseSync):
                     course.required_student = False
                     self.course_map[course_number] = course
                     if class_name and class_name in self.class_name_num:
-                        self.class_set.add(self.class_name_num[class_name])
+                        exist_class_sign = self.class_sign.get(class_name)
+                        if exist_class_sign and current_course_table != exist_class_sign:
+                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, exist_class_sign))
+                            continue
+                        self.class_set[current_course_table].add(self.class_name_num[class_name])
+                        self.class_sign[class_name] = current_course_table
+                    self.classroom_set[current_course_table].add(classroom_number)
+                    self.classroom_sign[classroom_number] = current_course_table
+                    self.course_container[current_course_table].append(course)
                 else:
                     course = self.course_map[course_number]
                 if is_teacher:
